.. -*- mode: rst -*-

.. |ReadTheDocs| image:: https://readthedocs.org/projects/scikit-mlmlm/badge/?version=latest
.. _ReadTheDocs: https://scikit-mlmlm.readthedocs.io/en/latest/?badge=latest

scikit-mlmlm - A python and sklearn compatible implementation of ML-MLM.
========================================================================

`scikit-mlmlm` is a Python and scikit-learn compatible implementation of Minimal Learning Machine - Multi Label Classifier, based on the Arxiv paper `Minimal Learning Machine for Multi-Label Learning <https://arxiv.org/abs/2305.05518>`_ and the GitHub repository https://github.com/jookriha/ml-mlm.

`Example Implementation: <https://colab.research.google.com/drive/1g5IpGNUSsZvE_bKCN3vXX8gxIRnjHmxC?usp=sharing>`_

A quick demo can be found in `ml_mlmlm_demo.py` at the root of the project.
